summaryrefslogtreecommitdiff
path: root/hw/xwin
diff options
context:
space:
mode:
Diffstat (limited to 'hw/xwin')
-rw-r--r--hw/xwin/InitInput.c2
-rw-r--r--hw/xwin/InitOutput.c17
-rw-r--r--hw/xwin/XWin.man18
-rw-r--r--hw/xwin/XWin.rc10
-rw-r--r--hw/xwin/ddraw.h1
-rw-r--r--hw/xwin/win.h2
-rw-r--r--hw/xwin/winallpriv.c2
-rw-r--r--hw/xwin/winblock.c2
-rw-r--r--hw/xwin/winclip.c2
-rw-r--r--hw/xwin/winclipboard.h2
-rw-r--r--hw/xwin/winclipboardinit.c2
-rw-r--r--hw/xwin/winclipboardtextconv.c2
-rw-r--r--hw/xwin/winclipboardthread.c2
-rw-r--r--hw/xwin/winclipboardunicode.c2
-rw-r--r--hw/xwin/winclipboardwndproc.c2
-rw-r--r--hw/xwin/winclipboardxevents.c2
-rw-r--r--hw/xwin/wincmap.c2
-rw-r--r--hw/xwin/winconfig.c9
-rw-r--r--hw/xwin/winconfig.h1
-rw-r--r--hw/xwin/wincreatewnd.c2
-rw-r--r--hw/xwin/wincursor.c2
-rwxr-xr-xhw/xwin/windialogs.c2
-rw-r--r--hw/xwin/winengine.c2
-rw-r--r--hw/xwin/winerror.c2
-rw-r--r--hw/xwin/winfillsp.c2
-rw-r--r--hw/xwin/winfont.c2
-rw-r--r--hw/xwin/wingc.c2
-rw-r--r--hw/xwin/wingetsp.c2
-rw-r--r--hw/xwin/winkeybd.c2
-rw-r--r--hw/xwin/winkeybd.h4
-rw-r--r--hw/xwin/winmisc.c2
-rw-r--r--hw/xwin/winmouse.c2
-rw-r--r--hw/xwin/winms.h2
-rw-r--r--hw/xwin/winmsg.c2
-rw-r--r--hw/xwin/winmsg.h2
-rwxr-xr-xhw/xwin/winmultiwindowclass.c2
-rwxr-xr-xhw/xwin/winmultiwindowclass.h2
-rwxr-xr-xhw/xwin/winmultiwindowicons.c2
-rwxr-xr-xhw/xwin/winmultiwindowshape.c2
-rw-r--r--hw/xwin/winmultiwindowwindow.c2
-rw-r--r--hw/xwin/winmultiwindowwm.c2
-rwxr-xr-xhw/xwin/winmultiwindowwndproc.c2
-rw-r--r--hw/xwin/winnativegdi.c2
-rw-r--r--hw/xwin/winpfbdd.c2
-rw-r--r--hw/xwin/winpixmap.c2
-rw-r--r--hw/xwin/winpntwin.c2
-rw-r--r--hw/xwin/winpolyline.c2
-rw-r--r--hw/xwin/winprefs.c2
-rw-r--r--hw/xwin/winprefs.h2
-rw-r--r--hw/xwin/winprefslex.l2
-rw-r--r--hw/xwin/winprefsyacc.y2
-rw-r--r--hw/xwin/winpushpxl.c2
-rw-r--r--hw/xwin/winregistry.c2
-rw-r--r--hw/xwin/winrop.c2
-rw-r--r--hw/xwin/winscrinit.c2
-rw-r--r--hw/xwin/winsetsp.c2
-rw-r--r--hw/xwin/winshaddd.c4
-rw-r--r--hw/xwin/winshadddnl.c2
-rw-r--r--hw/xwin/winshadgdi.c2
-rwxr-xr-xhw/xwin/wintrayicon.c4
-rwxr-xr-xhw/xwin/winvideo.c4
-rw-r--r--hw/xwin/winwakeup.c2
-rw-r--r--hw/xwin/winwindow.c2
-rw-r--r--hw/xwin/winwindow.h12
-rw-r--r--hw/xwin/winwndproc.c2
65 files changed, 100 insertions, 92 deletions
diff --git a/hw/xwin/InitInput.c b/hw/xwin/InitInput.c
index de84a7aee..92fb5c3e5 100644
--- a/hw/xwin/InitInput.c
+++ b/hw/xwin/InitInput.c
@@ -26,7 +26,7 @@
from The Open Group.
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/InitInput.c,v 1.13 2003/07/29 21:25:15 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/InitInput.c,v 1.11 2002/07/05 09:19:25 alanh Exp $ */
#include "win.h"
#include "../../Xext/xf86miscproc.h"
diff --git a/hw/xwin/XWin.man b/hw/xwin/XWin.man
index fe78047c4..3fb3f2814 100644
--- a/hw/xwin/XWin.man
+++ b/hw/xwin/XWin.man
@@ -1,4 +1,4 @@
-.\" $XFree86: xc/programs/Xserver/hw/xwin/XWin.man,v 1.7 2003/10/02 13:30:09 eich Exp $
+.\" $XFree86: xc/programs/Xserver/hw/xwin/XWin.man,v 1.5 2002/07/05 09:19:25 alanh Exp $
.TH XWIN 1 __vendorversion__
.SH NAME
XWin \- X Server for the Cygwin environment on Microsoft Windows
@@ -48,13 +48,13 @@ Sets the display resolution for the X server to use on screen
.I screen_number.
.TP 8
.B \-nodecoration
-Draw the Cygwin/XFree86 window without a border or title bar.
+Draw the Cygwin/X window without a border or title bar.
.TP 8
.B \-rootless
-EXPERIMENTAL: Run Cygwin/XFree86 in pseduo-rootless mode.
+EXPERIMENTAL: Run Cygwin/X in pseduo-rootless mode.
.TP 8
.B \-lesspointer
-Hide the Windows mouse pointer when over an inactive XFree86 window
+Hide the Windows mouse pointer when over an inactive X window
.TP 8
.B \-scrollbars
In windowed mode, allow screens bigger than the Windows desktop.
@@ -96,14 +96,14 @@ ones are:
- The display mode can not be changed once the X server has started.
.PP
.SH AUTHORS
-XFree86 was originally ported to Cygwin by Dakshinamurthy Karra,
+X was originally ported to Cygwin by Dakshinamurthy Karra,
Dr. Peter Busch, John Fortin, and Suhaib Siddiqi.
.I XWin
-is maintained by the Cygwin/XFree86 project, with hosting services
-provided by RedHat.
+is maintained by the Cygwin/X project, with hosting services
+provided by freedesktop.org.
.PP
The following members, in alphabetical order by last name, of the
-Cygwin/XFree86 Team contributed to the XFree86 4.1.0 release:
+Cygwin/X Team contributed to the X.Org Foundation 6.7 release:
.PP
Robert Collins - Cygwin developer, miscellaneous
.br
@@ -112,7 +112,7 @@ programming guru
.br
Alexander Gottwald - AltGr handling for non-U.S. keyboards
.br
-Alan Hourihane - XFree86 developer, patch reviewer, general programming guru
+Alan Hourihane - X developer, patch reviewer, general programming guru
.br
Pierre A Humblet - Debugging of socket-related crashes, developer
.br
diff --git a/hw/xwin/XWin.rc b/hw/xwin/XWin.rc
index 7b5708af2..2e6cceb47 100644
--- a/hw/xwin/XWin.rc
+++ b/hw/xwin/XWin.rc
@@ -27,7 +27,7 @@
*
* Authors: Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/XWin.rc,v 1.2 2003/07/29 21:25:15 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/XWin.rc,v 1.1 2002/10/17 08:18:21 alanh Exp $ */
#include "resource.h"
@@ -41,12 +41,12 @@
DEPTH_CHANGE_BOX DIALOG DISCARDABLE 32, 32, 180, 100
STYLE WS_POPUP | WS_CAPTION | WS_SYSMENU | WS_VISIBLE | DS_CENTER
FONT 8, "MS Sans Serif"
-CAPTION "Cygwin/XFree86"
+CAPTION "Cygwin/X"
BEGIN
DEFPUSHBUTTON "Dismiss", IDOK, 66, 80, 50, 14
- CTEXT "Cygwin/XFree86", IDC_STATIC, 40, 12, 100, 8
+ CTEXT "Cygwin/X", IDC_STATIC, 40, 12, 100, 8
CTEXT "Disruptive screen configuration change.", IDC_STATIC, 7, 40, 166, 8
- CTEXT "Restore previous resolution to use Cygwin/XFree86.", IDC_STATIC, 7, 52, 166, 8
+ CTEXT "Restore previous resolution to use Cygwin/X.", IDC_STATIC, 7, 52, 166, 8
END
@@ -55,7 +55,7 @@ END
EXIT_DIALOG DIALOG DISCARDABLE 32, 32, 180, 70
STYLE WS_POPUP | WS_CAPTION | WS_SYSMENU | WS_VISIBLE | WS_TABSTOP | DS_CENTER
FONT 8, "MS Sans Serif"
-CAPTION "Cygwin/XFree86 - Exit?"
+CAPTION "Cygwin/X - Exit?"
BEGIN
PUSHBUTTON "E&xit", IDOK, 55, 48, 30, 14
DEFPUSHBUTTON "&Cancel", IDCANCEL, 95, 48, 30, 14
diff --git a/hw/xwin/ddraw.h b/hw/xwin/ddraw.h
index b67a556b5..fbbf2b8eb 100644
--- a/hw/xwin/ddraw.h
+++ b/hw/xwin/ddraw.h
@@ -1,4 +1,3 @@
-/* $XFree86: xc/programs/Xserver/hw/xwin/ddraw.h,v 1.4 2001/07/29 22:08:15 tsi Exp $ */
#ifndef __WINE_DDRAW_H
#define __WINE_DDRAW_H
diff --git a/hw/xwin/win.h b/hw/xwin/win.h
index 6ecf5ada0..53d0880ea 100644
--- a/hw/xwin/win.h
+++ b/hw/xwin/win.h
@@ -31,7 +31,7 @@
* Harold L Hunt II
* Kensuke Matsuzaki
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/win.h,v 1.38 2003/10/08 11:13:02 eich Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/win.h,v 1.37 2003/10/02 13:30:09 eich Exp $ */
#ifndef _WIN_H_
#define _WIN_H_
diff --git a/hw/xwin/winallpriv.c b/hw/xwin/winallpriv.c
index a27309598..0da136541 100644
--- a/hw/xwin/winallpriv.c
+++ b/hw/xwin/winallpriv.c
@@ -28,7 +28,7 @@
* Authors: Keith Packard, MIT X Consortium
* Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winallpriv.c,v 1.12 2002/10/31 23:04:39 alanh Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winallpriv.c,v 1.11 2002/10/17 08:18:21 alanh Exp $ */
#include "win.h"
diff --git a/hw/xwin/winblock.c b/hw/xwin/winblock.c
index cc057eed6..35463493b 100644
--- a/hw/xwin/winblock.c
+++ b/hw/xwin/winblock.c
@@ -27,7 +27,7 @@
*
* Authors: Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winblock.c,v 1.7 2003/07/29 21:25:16 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winblock.c,v 1.5 2002/10/17 08:18:22 alanh Exp $ */
#include "win.h"
diff --git a/hw/xwin/winclip.c b/hw/xwin/winclip.c
index a829e8eb9..b8d10365d 100644
--- a/hw/xwin/winclip.c
+++ b/hw/xwin/winclip.c
@@ -27,7 +27,7 @@
*
* Authors: Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winclip.c,v 1.2 2001/06/04 13:04:41 alanh Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winclip.c,v 1.1 2001/04/05 20:13:49 dawes Exp $ */
#include "win.h"
diff --git a/hw/xwin/winclipboard.h b/hw/xwin/winclipboard.h
index 8f9bae789..3e7c22fa0 100644
--- a/hw/xwin/winclipboard.h
+++ b/hw/xwin/winclipboard.h
@@ -27,7 +27,7 @@
*
* Authors: Harold Hunt
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winclipboard.h,v 1.3 2003/10/02 13:30:10 eich Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winwindow.c,v 1.5 2002/11/07 10:31:32 alanh Exp $ */
#ifndef _WINCLIPBOARD_H_
diff --git a/hw/xwin/winclipboardinit.c b/hw/xwin/winclipboardinit.c
index a1f7b0b6d..0a1977759 100644
--- a/hw/xwin/winclipboardinit.c
+++ b/hw/xwin/winclipboardinit.c
@@ -27,7 +27,7 @@
*
* Authors: Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winclipboardinit.c,v 1.2 2003/07/29 21:25:16 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winclip.c,v 1.2 2001/06/04 13:04:41 alanh Exp $ */
#include "winclipboard.h"
diff --git a/hw/xwin/winclipboardtextconv.c b/hw/xwin/winclipboardtextconv.c
index 09ef40076..2f11b9241 100644
--- a/hw/xwin/winclipboardtextconv.c
+++ b/hw/xwin/winclipboardtextconv.c
@@ -27,7 +27,7 @@
*
* Authors: Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winclipboardtextconv.c,v 1.2 2003/07/29 21:25:16 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winclip.c,v 1.2 2001/06/04 13:04:41 alanh Exp $ */
#include "win.h"
#include <stdio.h>
diff --git a/hw/xwin/winclipboardthread.c b/hw/xwin/winclipboardthread.c
index 06a985533..7a746a0b3 100644
--- a/hw/xwin/winclipboardthread.c
+++ b/hw/xwin/winclipboardthread.c
@@ -27,7 +27,7 @@
*
* Authors: Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winclipboardthread.c,v 1.3 2003/10/02 13:30:10 eich Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winclip.c,v 1.2 2001/06/04 13:04:41 alanh Exp $ */
#include "winclipboard.h"
diff --git a/hw/xwin/winclipboardunicode.c b/hw/xwin/winclipboardunicode.c
index 9eb2b0d87..bda09b79f 100644
--- a/hw/xwin/winclipboardunicode.c
+++ b/hw/xwin/winclipboardunicode.c
@@ -27,7 +27,7 @@
*
* Authors: Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winclipboardunicode.c,v 1.2 2003/07/29 21:25:16 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winclip.c,v 1.2 2001/06/04 13:04:41 alanh Exp $ */
#include "win.h"
diff --git a/hw/xwin/winclipboardwndproc.c b/hw/xwin/winclipboardwndproc.c
index c577d060e..f8e52a0ef 100644
--- a/hw/xwin/winclipboardwndproc.c
+++ b/hw/xwin/winclipboardwndproc.c
@@ -27,7 +27,7 @@
*
* Authors: Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winclipboardwndproc.c,v 1.2 2003/07/29 21:25:16 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winclip.c,v 1.2 2001/06/04 13:04:41 alanh Exp $ */
#include "winclipboard.h"
diff --git a/hw/xwin/winclipboardxevents.c b/hw/xwin/winclipboardxevents.c
index 8b3a56489..d2cfb2e55 100644
--- a/hw/xwin/winclipboardxevents.c
+++ b/hw/xwin/winclipboardxevents.c
@@ -27,7 +27,7 @@
*
* Authors: Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winclipboardxevents.c,v 1.3 2003/10/02 13:30:10 eich Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winclip.c,v 1.2 2001/06/04 13:04:41 alanh Exp $ */
#include "winclipboard.h"
diff --git a/hw/xwin/wincmap.c b/hw/xwin/wincmap.c
index 4fb89a2fd..f89c26cf0 100644
--- a/hw/xwin/wincmap.c
+++ b/hw/xwin/wincmap.c
@@ -30,7 +30,7 @@
* Peter Busch
* Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/wincmap.c,v 1.10 2002/10/17 08:18:22 alanh Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/wincmap.c,v 1.9 2002/07/05 09:19:26 alanh Exp $ */
#include "win.h"
diff --git a/hw/xwin/winconfig.c b/hw/xwin/winconfig.c
index b42b1d6bf..d62fb18d9 100644
--- a/hw/xwin/winconfig.c
+++ b/hw/xwin/winconfig.c
@@ -27,7 +27,7 @@
*
* Authors: Alexander Gottwald
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winconfig.c,v 1.4 2003/10/08 11:13:02 eich Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winconfig.c,v 1.3 2003/10/02 13:30:10 eich Exp $ */
#include "win.h"
#include "winconfig.h"
@@ -126,6 +126,11 @@ winReadConfigfile ()
/* Parse config file into data structure */
filename = xf86openConfigFile (CONFIGPATH, xf86ConfigFile, PROJECTROOT);
+
+ /* Hack for backward compatibility */
+ if (!filename && from == X_DEFAULT)
+ filename = xf86openConfigFile (CONFIGPATH, "XF86Config", PROJECTROOT);
+
if (filename)
{
winMsg (from, "Using config file: \"%s\"\n", filename);
@@ -258,7 +263,7 @@ winConfigKeyboard (DeviceIntPtr pDevice)
g_winInfo.xkb.variant = NULL;
g_winInfo.xkb.options = NULL;
# else
- g_winInfo.xkb.rules = "xfree86";
+ g_winInfo.xkb.rules = "xorg";
g_winInfo.xkb.model = "pc101";
g_winInfo.xkb.layout = "us";
g_winInfo.xkb.variant = NULL;
diff --git a/hw/xwin/winconfig.h b/hw/xwin/winconfig.h
index d3099b373..6f07ea9bc 100644
--- a/hw/xwin/winconfig.h
+++ b/hw/xwin/winconfig.h
@@ -27,7 +27,6 @@
*
* Authors: Alexander Gottwald
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winconfig.h,v 1.1 2002/10/17 08:18:22 alanh Exp $ */
#ifndef __WIN_CONFIG_H__
#define __WIN_CONFIG_H__
diff --git a/hw/xwin/wincreatewnd.c b/hw/xwin/wincreatewnd.c
index 336131c8a..10d2273cd 100644
--- a/hw/xwin/wincreatewnd.c
+++ b/hw/xwin/wincreatewnd.c
@@ -27,7 +27,7 @@
*
* Authors: Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/wincreatewnd.c,v 1.7 2003/10/08 11:13:03 eich Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/wincreatewnd.c,v 1.4 2002/10/17 08:18:22 alanh Exp $ */
#include "win.h"
#include "shellapi.h"
diff --git a/hw/xwin/wincursor.c b/hw/xwin/wincursor.c
index e7c3ba7e7..9e053a7d2 100644
--- a/hw/xwin/wincursor.c
+++ b/hw/xwin/wincursor.c
@@ -30,7 +30,7 @@
* Peter Busch
* Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/wincursor.c,v 1.6 2003/07/29 21:25:17 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/wincursor.c,v 1.5 2002/07/05 09:19:26 alanh Exp $ */
#include "win.h"
diff --git a/hw/xwin/windialogs.c b/hw/xwin/windialogs.c
index d905ad81c..07db55075 100755
--- a/hw/xwin/windialogs.c
+++ b/hw/xwin/windialogs.c
@@ -27,7 +27,7 @@
*
* Authors: Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/windialogs.c,v 1.1 2003/07/29 21:25:17 dawes Exp $ */
+/* $XFree86: $ */
#include "win.h"
diff --git a/hw/xwin/winengine.c b/hw/xwin/winengine.c
index d76e58628..c8c2ef40f 100644
--- a/hw/xwin/winengine.c
+++ b/hw/xwin/winengine.c
@@ -27,7 +27,7 @@
*
* Authors: Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winengine.c,v 1.5 2003/07/29 21:25:17 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winengine.c,v 1.3 2002/07/05 09:19:26 alanh Exp $ */
#include "win.h"
diff --git a/hw/xwin/winerror.c b/hw/xwin/winerror.c
index 8a1e0df85..fa6687c1b 100644
--- a/hw/xwin/winerror.c
+++ b/hw/xwin/winerror.c
@@ -27,7 +27,7 @@
*
* Authors: Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winerror.c,v 1.6 2003/10/02 13:30:10 eich Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winerror.c,v 1.3 2001/10/23 22:22:47 alanh Exp $ */
#include "win.h"
diff --git a/hw/xwin/winfillsp.c b/hw/xwin/winfillsp.c
index 9ac536274..556fde718 100644
--- a/hw/xwin/winfillsp.c
+++ b/hw/xwin/winfillsp.c
@@ -28,7 +28,7 @@
* Authors: Harold L Hunt II
* Alan Hourihane <alanh@fairlite.demon.co.uk>
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winfillsp.c,v 1.10 2003/08/07 23:47:58 alanh Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winfillsp.c,v 1.9 2001/11/01 12:19:40 alanh Exp $ */
#include "win.h"
diff --git a/hw/xwin/winfont.c b/hw/xwin/winfont.c
index 97bd7967b..a6ff2f7da 100644
--- a/hw/xwin/winfont.c
+++ b/hw/xwin/winfont.c
@@ -27,7 +27,7 @@
*
* Authors: Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winfont.c,v 1.3 2003/08/07 23:47:58 alanh Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winfont.c,v 1.2 2001/06/04 13:04:41 alanh Exp $ */
#include "win.h"
diff --git a/hw/xwin/wingc.c b/hw/xwin/wingc.c
index a4e2a53cb..ce0ef6584 100644
--- a/hw/xwin/wingc.c
+++ b/hw/xwin/wingc.c
@@ -27,7 +27,7 @@
*
* Authors: Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/wingc.c,v 1.11 2003/08/07 23:47:58 alanh Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/wingc.c,v 1.10 2001/10/30 15:39:09 alanh Exp $ */
#include "win.h"
void
diff --git a/hw/xwin/wingetsp.c b/hw/xwin/wingetsp.c
index 49ba7f2fb..79dc5eb53 100644
--- a/hw/xwin/wingetsp.c
+++ b/hw/xwin/wingetsp.c
@@ -28,7 +28,7 @@
* Authors: Harold L Hunt II
* Alan Hourihane <alanh@fairlite.demon.co.uk>
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/wingetsp.c,v 1.8 2003/08/07 23:47:58 alanh Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/wingetsp.c,v 1.7 2001/11/01 12:19:40 alanh Exp $ */
#include "win.h"
diff --git a/hw/xwin/winkeybd.c b/hw/xwin/winkeybd.c
index 95f245e57..4228ad422 100644
--- a/hw/xwin/winkeybd.c
+++ b/hw/xwin/winkeybd.c
@@ -30,7 +30,7 @@
* Peter Busch
* Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winkeybd.c,v 1.13 2003/07/29 21:25:17 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winkeybd.c,v 1.12 2002/10/17 08:18:22 alanh Exp $ */
#include "win.h"
diff --git a/hw/xwin/winkeybd.h b/hw/xwin/winkeybd.h
index 0822b0e5f..375245f80 100644
--- a/hw/xwin/winkeybd.h
+++ b/hw/xwin/winkeybd.h
@@ -27,7 +27,7 @@
*
* Authors: Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winkeybd.h,v 1.3 2002/07/05 09:19:26 alanh Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winkeybd.h,v 1.1 2001/09/26 13:00:34 alanh Exp $ */
/*
* We need symbols for the scan codes of keys.
@@ -36,7 +36,7 @@
/*
- * Include the standard XFree86 ASCII keymap.
+ * Include the standard ASCII keymap.
*
* This header declares a static KeySym array called 'map'.
*/
diff --git a/hw/xwin/winmisc.c b/hw/xwin/winmisc.c
index ea8303ea9..e93d1fd93 100644
--- a/hw/xwin/winmisc.c
+++ b/hw/xwin/winmisc.c
@@ -27,7 +27,7 @@
*
* Authors: Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winmisc.c,v 1.6 2002/07/05 09:19:26 alanh Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winmisc.c,v 1.5 2001/11/11 22:45:57 alanh Exp $ */
#include "win.h"
diff --git a/hw/xwin/winmouse.c b/hw/xwin/winmouse.c
index 8c9439bfd..ef3a2eb92 100644
--- a/hw/xwin/winmouse.c
+++ b/hw/xwin/winmouse.c
@@ -30,7 +30,7 @@
* Peter Busch
* Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winmouse.c,v 1.4 2001/10/29 21:10:24 alanh Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winmouse.c,v 1.3 2001/05/08 08:14:09 alanh Exp $ */
#include "win.h"
diff --git a/hw/xwin/winms.h b/hw/xwin/winms.h
index 17454487d..ad20348b6 100644
--- a/hw/xwin/winms.h
+++ b/hw/xwin/winms.h
@@ -27,7 +27,7 @@
*
* Authors: Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winms.h,v 1.2 2001/04/18 17:14:06 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winms.h,v 1.1 2001/04/05 20:13:50 dawes Exp $ */
#ifndef _WINMS_H_
#define _WINMS_H_
diff --git a/hw/xwin/winmsg.c b/hw/xwin/winmsg.c
index ce8ac4199..8d42d95a0 100644
--- a/hw/xwin/winmsg.c
+++ b/hw/xwin/winmsg.c
@@ -27,7 +27,7 @@
*
* Authors: Alexander Gottwald
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winmsg.c,v 1.2 2003/10/02 13:30:10 eich Exp $ */
+/* $XFree86$ */
#include "win.h"
#include "winmsg.h"
diff --git a/hw/xwin/winmsg.h b/hw/xwin/winmsg.h
index 16ec536b0..136cdc3a8 100644
--- a/hw/xwin/winmsg.h
+++ b/hw/xwin/winmsg.h
@@ -27,7 +27,7 @@
*
* Authors: Alexander Gottwald
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winmsg.h,v 1.2 2003/10/02 13:30:10 eich Exp $ */
+/* $XFree86$ */
#ifndef __WIN_MSG_H__
#define __WIN_MSG_H__
diff --git a/hw/xwin/winmultiwindowclass.c b/hw/xwin/winmultiwindowclass.c
index 21be64977..be65bd153 100755
--- a/hw/xwin/winmultiwindowclass.c
+++ b/hw/xwin/winmultiwindowclass.c
@@ -27,7 +27,7 @@
*
* Authors: Earle F. Philhower, III
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winmultiwindowclass.c,v 1.2 2003/10/02 13:30:10 eich Exp $ */
+/* $XFree86$ */
#include <Xatom.h>
#include "propertyst.h"
diff --git a/hw/xwin/winmultiwindowclass.h b/hw/xwin/winmultiwindowclass.h
index b6ad55d8b..f9cfee30f 100755
--- a/hw/xwin/winmultiwindowclass.h
+++ b/hw/xwin/winmultiwindowclass.h
@@ -27,7 +27,7 @@
*
* Authors: Earle F. Philhower, III
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winmultiwindowclass.h,v 1.2 2003/10/02 13:30:10 eich Exp $ */
+/* $XFree86$ */
/*
diff --git a/hw/xwin/winmultiwindowicons.c b/hw/xwin/winmultiwindowicons.c
index dd56db6d6..33b9391a8 100755
--- a/hw/xwin/winmultiwindowicons.c
+++ b/hw/xwin/winmultiwindowicons.c
@@ -27,7 +27,7 @@
*
* Authors: Earle F. Philhower, III
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winmultiwindowicons.c,v 1.2 2003/10/02 13:30:10 eich Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winwindow.c,v 1.5 2002/11/07 10:31:32 alanh Exp $ */
#include "win.h"
#include "dixevents.h"
diff --git a/hw/xwin/winmultiwindowshape.c b/hw/xwin/winmultiwindowshape.c
index 2d6a6f2cc..a21bbe9f3 100755
--- a/hw/xwin/winmultiwindowshape.c
+++ b/hw/xwin/winmultiwindowshape.c
@@ -28,7 +28,7 @@
* Authors: Kensuke Matsuzaki
* Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winmultiwindowshape.c,v 1.3 2003/12/22 01:34:20 dickey Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winmultiwindowshape.c,v 1.2 2003/11/10 18:22:44 tsi Exp $ */
#ifdef SHAPE
diff --git a/hw/xwin/winmultiwindowwindow.c b/hw/xwin/winmultiwindowwindow.c
index 15e508659..1430b7d88 100644
--- a/hw/xwin/winmultiwindowwindow.c
+++ b/hw/xwin/winmultiwindowwindow.c
@@ -29,7 +29,7 @@
* Earle F. Philhower, III
* Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winmultiwindowwindow.c,v 1.3 2003/10/02 13:30:10 eich Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winwindow.c,v 1.5 2002/11/07 10:31:32 alanh Exp $ */
#include "win.h"
#include "dixevents.h"
diff --git a/hw/xwin/winmultiwindowwm.c b/hw/xwin/winmultiwindowwm.c
index a60d36135..f77a40476 100644
--- a/hw/xwin/winmultiwindowwm.c
+++ b/hw/xwin/winmultiwindowwm.c
@@ -27,7 +27,7 @@
*
* Authors: Kensuke Matsuzaki
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winmultiwindowwm.c,v 1.3 2003/10/02 13:30:11 eich Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winwindow.c,v 1.5 2002/11/07 10:31:32 alanh Exp $ */
/* X headers */
#include <stdio.h>
diff --git a/hw/xwin/winmultiwindowwndproc.c b/hw/xwin/winmultiwindowwndproc.c
index d90abb61f..83f3b02f6 100755
--- a/hw/xwin/winmultiwindowwndproc.c
+++ b/hw/xwin/winmultiwindowwndproc.c
@@ -29,7 +29,7 @@
* Earle F. Philhower, III
* Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winmultiwindowwndproc.c,v 1.3 2003/10/08 11:13:03 eich Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winmultiwindowwndproc.c,v 1.2 2003/10/02 13:30:11 eich Exp $ */
#include "win.h"
#include "dixevents.h"
diff --git a/hw/xwin/winnativegdi.c b/hw/xwin/winnativegdi.c
index f7d8a4a1a..b2ac9f14e 100644
--- a/hw/xwin/winnativegdi.c
+++ b/hw/xwin/winnativegdi.c
@@ -27,7 +27,7 @@
*
* Authors: Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winnativegdi.c,v 1.15 2003/08/07 23:47:58 alanh Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winnativegdi.c,v 1.14 2003/07/29 21:25:18 dawes Exp $ */
#include "win.h"
diff --git a/hw/xwin/winpfbdd.c b/hw/xwin/winpfbdd.c
index 7cbdb5e53..33cb42eb1 100644
--- a/hw/xwin/winpfbdd.c
+++ b/hw/xwin/winpfbdd.c
@@ -30,7 +30,7 @@
* Peter Busch
* Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winpfbdd.c,v 1.18 2003/07/29 21:25:18 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winpfbdd.c,v 1.17 2002/10/17 08:18:22 alanh Exp $ */
#include "win.h"
diff --git a/hw/xwin/winpixmap.c b/hw/xwin/winpixmap.c
index 43ade059b..24e49719a 100644
--- a/hw/xwin/winpixmap.c
+++ b/hw/xwin/winpixmap.c
@@ -28,7 +28,7 @@
* Authors: drewry, september 1986
* Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winpixmap.c,v 1.11 2003/08/07 23:47:58 alanh Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winpixmap.c,v 1.10 2002/10/17 08:18:24 alanh Exp $ */
#include "win.h"
diff --git a/hw/xwin/winpntwin.c b/hw/xwin/winpntwin.c
index d28929d67..46d738209 100644
--- a/hw/xwin/winpntwin.c
+++ b/hw/xwin/winpntwin.c
@@ -27,7 +27,7 @@
*
* Authors: Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winpntwin.c,v 1.2 2001/06/04 13:04:41 alanh Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winpntwin.c,v 1.1 2001/04/05 20:13:50 dawes Exp $ */
#include "win.h"
diff --git a/hw/xwin/winpolyline.c b/hw/xwin/winpolyline.c
index 948c34428..baafd8c39 100644
--- a/hw/xwin/winpolyline.c
+++ b/hw/xwin/winpolyline.c
@@ -27,7 +27,7 @@
*
* Authors: Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winpolyline.c,v 1.4 2003/08/07 23:47:58 alanh Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winpolyline.c,v 1.3 2001/09/13 08:25:45 alanh Exp $ */
#include "win.h"
diff --git a/hw/xwin/winprefs.c b/hw/xwin/winprefs.c
index 3bea60d3d..b0a5d49ee 100644
--- a/hw/xwin/winprefs.c
+++ b/hw/xwin/winprefs.c
@@ -27,7 +27,7 @@
*
* Authors: Earle F. Philhower, III
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winprefs.c,v 1.1 2003/10/02 13:30:11 eich Exp $ */
+/* $XFree86: $ */
#include <stdio.h>
#include <stdlib.h>
diff --git a/hw/xwin/winprefs.h b/hw/xwin/winprefs.h
index ae1cb07d8..4ae01c081 100644
--- a/hw/xwin/winprefs.h
+++ b/hw/xwin/winprefs.h
@@ -27,7 +27,7 @@
*
* Authors: Earle F. Philhower, III
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winprefs.h,v 1.1 2003/10/02 13:30:11 eich Exp $ */
+/* $XFree86: $ */
/* Need to know how long paths can be... */
#include <limits.h>
diff --git a/hw/xwin/winprefslex.l b/hw/xwin/winprefslex.l
index 8eda8e6c2..960183498 100644
--- a/hw/xwin/winprefslex.l
+++ b/hw/xwin/winprefslex.l
@@ -28,7 +28,7 @@
*
* Authors: Earle F. Philhower, III
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winprefslex.l,v 1.1 2003/10/02 13:30:11 eich Exp $ */
+/* $XFree86: $ */
#include <stdio.h>
#include <stdlib.h>
diff --git a/hw/xwin/winprefsyacc.y b/hw/xwin/winprefsyacc.y
index a6ffc7207..5ae33b67e 100644
--- a/hw/xwin/winprefsyacc.y
+++ b/hw/xwin/winprefsyacc.y
@@ -28,7 +28,7 @@
*
* Authors: Earle F. Philhower, III
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winprefsyacc.y,v 1.1 2003/10/02 13:30:11 eich Exp $ */
+/* $XFree86: $ */
#include <stdio.h>
#include <stdlib.h>
diff --git a/hw/xwin/winpushpxl.c b/hw/xwin/winpushpxl.c
index deb9629d7..2ae0e6557 100644
--- a/hw/xwin/winpushpxl.c
+++ b/hw/xwin/winpushpxl.c
@@ -1,4 +1,4 @@
-/* $XFree86: xc/programs/Xserver/hw/xwin/winpushpxl.c,v 1.1 2003/08/07 23:47:58 alanh Exp $ */
+/* $XFree86: xc/programs/Xserver/mi/mipushpxl.c,v 3.11 2001/01/17 22:37:07 dawes Exp $ */
/***********************************************************
Copyright 1987, 1998 The Open Group
diff --git a/hw/xwin/winregistry.c b/hw/xwin/winregistry.c
index b31fcf641..7d4a473ab 100644
--- a/hw/xwin/winregistry.c
+++ b/hw/xwin/winregistry.c
@@ -27,7 +27,7 @@
*
* Authors: Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winregistry.c,v 1.1 2002/07/05 09:19:26 alanh Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winmisc.c,v 1.5 2001/11/11 22:45:57 alanh Exp $ */
#include "win.h"
diff --git a/hw/xwin/winrop.c b/hw/xwin/winrop.c
index c5ec45de5..76a997aaa 100644
--- a/hw/xwin/winrop.c
+++ b/hw/xwin/winrop.c
@@ -27,7 +27,7 @@
*
* Authors: Alan Hourihane <alanh@fairlite.demon.co.uk>
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winrop.c,v 1.1 2003/08/07 23:47:58 alanh Exp $ */
+/* $XFree86$ */
/*
* Raster operations used by Windows translated to X's 16 rop codes...
diff --git a/hw/xwin/winscrinit.c b/hw/xwin/winscrinit.c
index 79e985c6b..595f3da7e 100644
--- a/hw/xwin/winscrinit.c
+++ b/hw/xwin/winscrinit.c
@@ -31,7 +31,7 @@
* Harold L Hunt II
* Kensuke Matsuzaki
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winscrinit.c,v 1.28 2003/08/07 23:47:58 alanh Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winscrinit.c,v 1.27 2003/07/29 21:25:18 dawes Exp $ */
#include "win.h"
diff --git a/hw/xwin/winsetsp.c b/hw/xwin/winsetsp.c
index c0340e47b..87a16fc31 100644
--- a/hw/xwin/winsetsp.c
+++ b/hw/xwin/winsetsp.c
@@ -28,7 +28,7 @@
* Authors: Harold L Hunt II
* Alan Hourihane <alanh@fairlite.demon.co.uk>
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winsetsp.c,v 1.8 2003/08/07 23:47:58 alanh Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winsetsp.c,v 1.7 2001/11/01 12:19:42 alanh Exp $ */
#include "win.h"
diff --git a/hw/xwin/winshaddd.c b/hw/xwin/winshaddd.c
index a409c27c6..239c0f5ab 100644
--- a/hw/xwin/winshaddd.c
+++ b/hw/xwin/winshaddd.c
@@ -30,7 +30,7 @@
* Peter Busch
* Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winshaddd.c,v 1.24 2003/07/29 21:25:18 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winshaddd.c,v 1.22 2002/10/17 08:18:24 alanh Exp $ */
#include "win.h"
@@ -573,7 +573,7 @@ winShadowUpdateDD (ScreenPtr pScreen,
ErrorF ("winShadowUpdateProcDD - Memory location of the shadow "
"surface has changed, trying to update the root window "
"pixmap header to point to the new address. If you get "
- "this message and Cygwin/XFree86 freezes or crashes "
+ "this message and Cygwin/X freezes or crashes "
"after this message then send a problem report and your "
"/tmp/XWin.log file to cygwin-xfree@cygwin.com\n");
diff --git a/hw/xwin/winshadddnl.c b/hw/xwin/winshadddnl.c
index e902f31b0..a5e09421e 100644
--- a/hw/xwin/winshadddnl.c
+++ b/hw/xwin/winshadddnl.c
@@ -30,7 +30,7 @@
* Peter Busch
* Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winshadddnl.c,v 1.26 2003/10/02 13:30:11 eich Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winshadddnl.c,v 1.23 2002/10/17 08:18:25 alanh Exp $ */
#include "win.h"
diff --git a/hw/xwin/winshadgdi.c b/hw/xwin/winshadgdi.c
index 16b1969d7..29ce6761b 100644
--- a/hw/xwin/winshadgdi.c
+++ b/hw/xwin/winshadgdi.c
@@ -27,7 +27,7 @@
*
* Authors: Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winshadgdi.c,v 1.23 2003/07/29 21:25:18 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winshadgdi.c,v 1.21 2002/10/17 08:18:25 alanh Exp $ */
#include "win.h"
diff --git a/hw/xwin/wintrayicon.c b/hw/xwin/wintrayicon.c
index 90c77b1c8..9ba507ad2 100755
--- a/hw/xwin/wintrayicon.c
+++ b/hw/xwin/wintrayicon.c
@@ -28,7 +28,7 @@
* Authors: Early Ehlinger
* Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/wintrayicon.c,v 1.2 2003/10/02 13:30:11 eich Exp $ */
+/* $XFree86: $ */
#include "win.h"
#include <shellapi.h>
@@ -62,7 +62,7 @@ winInitNotifyIcon (winPrivScreenPtr pScreenPriv)
/* Set display and screen-specific tooltip text */
snprintf (nid.szTip,
sizeof (nid.szTip),
- "Cygwin/XFree86 Server - %s:%d",
+ "Cygwin/X Server - %s:%d",
display,
(int) pScreenInfo->dwScreen);
diff --git a/hw/xwin/winvideo.c b/hw/xwin/winvideo.c
index 8bf12cd66..d4a856fcf 100755
--- a/hw/xwin/winvideo.c
+++ b/hw/xwin/winvideo.c
@@ -27,7 +27,7 @@
*
* Authors: Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winvideo.c,v 1.2 2003/11/10 18:22:44 tsi Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winvideo.c,v 1.1tsi Exp $ */
#include "win.h"
#include "Xv.h"
@@ -144,7 +144,7 @@ winSetupImageVideo (ScreenPtr pScreen)
adapt->type = XvWindowMask | XvInputMask | XvImageMask;
adapt->flags = VIDEO_OVERLAID_IMAGES | VIDEO_CLIP_TO_VIEWPORT;
- adapt->name = "Cygwin/XFree86 Video Overlay";
+ adapt->name = "Cygwin/X Video Overlay";
adapt->nEncodings = 1;
adapt->pEncodings = DummyEncoding;
adapt->nFormats = NUM_FORMATS;
diff --git a/hw/xwin/winwakeup.c b/hw/xwin/winwakeup.c
index f311d0dc9..55658ecac 100644
--- a/hw/xwin/winwakeup.c
+++ b/hw/xwin/winwakeup.c
@@ -30,7 +30,7 @@
* Peter Busch
* Harold L Hunt II
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winwakeup.c,v 1.7 2003/07/29 21:25:18 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winwakeup.c,v 1.6 2002/10/17 08:18:25 alanh Exp $ */
#include "win.h"
diff --git a/hw/xwin/winwindow.c b/hw/xwin/winwindow.c
index 76dfc5d89..378465bc4 100644
--- a/hw/xwin/winwindow.c
+++ b/hw/xwin/winwindow.c
@@ -28,7 +28,7 @@
* Authors: Harold L Hunt II
* Kensuke Matsuzaki
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winwindow.c,v 1.10 2003/12/22 01:34:20 dickey Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winwindow.c,v 1.9 2003/11/10 18:22:44 tsi Exp $ */
#include "win.h"
diff --git a/hw/xwin/winwindow.h b/hw/xwin/winwindow.h
index 8153b5600..b8e164c2b 100644
--- a/hw/xwin/winwindow.h
+++ b/hw/xwin/winwindow.h
@@ -27,7 +27,7 @@
*
* Authors: Kensuke Matsuzaki
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winwindow.h,v 1.4 2003/10/08 11:13:03 eich Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winwindow.h,v 1.3 2003/10/02 13:30:11 eich Exp $ */
#ifndef _WINWINDOW_H_
@@ -41,12 +41,12 @@
#endif
/* Constant strings */
-#define WINDOW_CLASS "cygwin/xfree86"
-#define WINDOW_TITLE "Cygwin/XFree86 - %s:%d"
-#define WINDOW_TITLE_XDMCP "Cygwin/XFree86 - %s"
+#define WINDOW_CLASS "cygwin/x"
+#define WINDOW_TITLE "Cygwin/X - %s:%d"
+#define WINDOW_TITLE_XDMCP "Cygwin/X - %s"
#define WIN_SCR_PROP "cyg_screen_prop rl"
-#define WINDOW_CLASS_X "cygwin/xfree86 X rl"
-#define WINDOW_TITLE_X "Cygwin/XFree86 X"
+#define WINDOW_CLASS_X "cygwin/x X rl"
+#define WINDOW_TITLE_X "Cygwin/X X"
#define WIN_WINDOW_PROP "cyg_window_prop_rl"
#define WIN_MSG_QUEUE_FNAME "/dev/windows"
#define WIN_LOG_FNAME "/tmp/XWin.log"
diff --git a/hw/xwin/winwndproc.c b/hw/xwin/winwndproc.c
index 5b47a212a..535882753 100644
--- a/hw/xwin/winwndproc.c
+++ b/hw/xwin/winwndproc.c
@@ -31,7 +31,7 @@
* Harold L Hunt II
* MATSUZAKI Kensuke
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/winwndproc.c,v 1.26 2003/10/02 13:30:11 eich Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/winwndproc.c,v 1.23 2002/10/17 08:18:25 alanh Exp $ */
#include "win.h"
#include <commctrl.h>
diff --git a/hw/xwin/InitOutput.c b/hw/xwin/InitOutput.c
index 3202ae8d9..68910be1a 100644
--- a/hw/xwin/InitOutput.c
+++ b/hw/xwin/InitOutput.c
@@ -26,7 +26,7 @@ other dealings in this Software without prior written authorization
from The Open Group.
*/
-/* $XFree86: xc/programs/Xserver/hw/xwin/InitOutput.c,v 1.35 2003/10/08 11:13:02 eich Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xwin/InitOutput.c,v 1.34 2003/10/02 13:30:09 eich Exp $ */
#include "win.h"
#include "winconfig.h"
@@ -312,7 +312,7 @@ ddxUseMsg (void)
ErrorF ("-lesspointer\n"
"\tHide the windows mouse pointer when it is over an inactive\n"
- "\tXFree86 window. This prevents ghost cursors appearing where\n"
+ "\tX window. This prevents ghost cursors appearing where\n"
"\tthe Windows cursor is drawn overtop of the X cursor\n");
ErrorF ("-nodecoration\n"
@@ -361,7 +361,7 @@ ddxUseMsg (void)
ErrorF ("-[no]winkill\n"
"\tAlt+F4 exits the X Server.\n");
- ErrorF ("-xf86config\n"
+ ErrorF ("-config\n"
"\tSpecify a configuration file.\n");
ErrorF ("-keyboard\n"
@@ -394,6 +394,11 @@ ddxUseMsg (void)
/* Compare the current option with the string. */
#define IS_OPTION(name) (strcmp (argv[i], name) == 0)
+/* ddxInitGlobals - called by |InitGlobals| from os/util.c */
+void ddxInitGlobals(void)
+{
+}
+
int
ddxProcessArgument (int argc, char *argv[], int i)
{
@@ -1201,9 +1206,9 @@ ddxProcessArgument (int argc, char *argv[], int i)
}
/*
* Look for the '-xf86config' argument
*/
- if (IS_OPTION ("-xf86config"))
+ if (IS_OPTION ("-config") || IS_OPTION ("-xf86config"))
{
CHECK_ARGS (1);
g_cmdline.configFile = argv[++i];
@@ -1270,7 +1275,7 @@ InitOutput (ScreenInfo *screenInfo, int argc, char *argv[])
ErrorF ("InitOutput\n");
#endif
- /* Try to read the XF86Config-style configuration file */
+ /* Try to read the xorg.conf-style configuration file */
if (!winReadConfigfile ())
ErrorF ("InitOutput - Error reading config file\n");
@@ -1201,9 +1206,9 @@ ddxProcessArgument (int argc, char *argv[], int i)
}
/*
- * Look for the '-xf86config' argument
+ * Look for the '-config' argument. Accept -xf86config as an alias
*/